﻿using System;
using System.Linq;
using System.Net.Mime;
using System.Web;
using System.Web.Mvc;
using DynamicsCRM.Models;
using DynamicsCRM.Services;
using Microsoft.Xrm.Client;
using Orchard;
using Orchard.Themes;
using Xrm;
using Microsoft.Xrm.Sdk;

namespace DynamicsCRM.Controllers {
    [Themed]
    public class CalendarController : Controller {
        private const string HomeUrl = "~/DynamicsCRM/Home";
        private const string RelUrl = "~/DynamicsCRM/Calendar";
        private static Guid _crmUserId = Guid.Empty;
        private readonly IXrmRepository _repository;

        public CalendarController(IOrchardServices orchardServices) {
            _repository = new XrmRepository(orchardServices);
        }

        public CalendarController(IXrmRepository repository) {
            _repository = repository;
        }

        [Authorize]
        public ActionResult Index() {
            //Retrieve the current contact
            _crmUserId = _repository.RetrieveMyIdByIdentifier();

            //Get a list of service calendar items
            if (_crmUserId != Guid.Empty)
            {
                var appointments = _repository.RetrieveAppointmentByParty(_crmUserId);
                if (appointments != null && appointments.Count() > 0)
                {
                    ViewData["appointments"] = appointments;
                }

                return View();
            }
            else //create a new CRM account
            {
                TempData["UserMessage"] = "You don't have a CRM account yet - please create your CRM account.";
                return Redirect(HomeUrl);
            }
        }

        [Authorize]
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Index(CalendarModel model)
        {
            return View(model);
        }

        [Authorize]
        public ActionResult Create(string resourceId)
        {
            //Retrieve the current contact
            _crmUserId = _repository.RetrieveMyIdByIdentifier();

            //Get a list of resources
            if (_crmUserId != Guid.Empty)
            {
                CalendarModel model = new CalendarModel();

                //var resources = _repository.RetrieveResourceByObjectType("equipment");
                var resources = _repository.RetrieveResourceByObjectType("systemuser");
                if (resources != null && resources.Count() > 0)
                {
                    model.Resource = new SelectList(resources, "ID", "Name");
                }

                var occupiedDates = _repository.RetrieveAppointmentOccupiedDateByResource(resourceId != null ? new Guid(resourceId) : Guid.Empty);
                if (occupiedDates != null && occupiedDates.Count() > 0)
                {
                    model.OccupiedDates = occupiedDates;
                }

                return View(model);
            }
            else //create a new CRM account
            {
                TempData["UserMessage"] = "You don't have a CRM account yet - please create your CRM account.";
                return Redirect(HomeUrl);
            }
        }

        [Authorize]
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create(CalendarModel model, string button)
        {
            if (button == "cancel")
            {
                return Redirect(RelUrl);
            }
            else if (button == null && model.ResourceItemId != null)
            {
                return Create(model.ResourceItemId);
            }

            if (ModelState.IsValid)
            {
                if (_crmUserId != Guid.Empty)
                {
                    if (model.ResourceItemId != null)
                    {
                        ActivityParty customer = new ActivityParty
                        {
                            PartyId = new EntityReference(Contact.EntityLogicalName, _crmUserId)
                        };

                        ActivityParty resource = new ActivityParty
                        {
                            //PartyId = new EntityReference(Equipment.EntityLogicalName, new Guid(model.ResourceItemId))
                            PartyId = new EntityReference(SystemUser.EntityLogicalName, new Guid(model.ResourceItemId))
                        };

                        //Create a new service appointment
                        var appointment = new Xrm.ServiceAppointment
                        {
                            Subject = model.Subject,
                            ScheduledStart = model.StartTime.AddHours(9),
                            ScheduledEnd = model.StartTime.AddHours(12),
                            Customers = new ActivityParty[] { customer },
                            Resources = new ActivityParty[] { resource },
                        };
                        _repository.CreateCrmRecord(appointment);

                        Index();
                        TempData["UserMessage"] = "A new service appointment has been created.";

                        return Redirect(RelUrl);
                    }
                }
                else //create a new CRM account
                {
                    TempData["UserMessage"] = "You don't have a CRM account yet - please create your CRM account.";
                    return Redirect(HomeUrl);
                }
            }


            ModelState.AddModelError("", "CRM service appointment create error.");
            return Create(model.ResourceItemId);
        }

    }
}